library charted.demo.charts;

import "package:charted/charts/charts.dart";

/// Helper method to create default behaviors for cartesian chart demos.
Iterable<ChartBehavior> createDefaultCartesianBehaviors() =>
    new List.from([
        new Hovercard(isMultiValue: true),
        new AxisLabelTooltip()
    ]);

/// Helper method to create default behaviors for layout chart demos.
Iterable<ChartBehavior> createDefaultLayoutBehaviors() =>
    new List.from([new ChartTooltip()]);

/// Sample columns used by demos with quantitative dimension scale
Iterable ORDINAL_DATA_COLUMNS = [
    new ChartColumnSpec(label: 'Month', type: ChartColumnSpec.TYPE_STRING),
    new ChartColumnSpec(label: 'Grains'),
    new ChartColumnSpec(label: 'Fruits'),
    new ChartColumnSpec(label: 'Vegetables')
];

/// Sample values used by demos with quantitative dimension scale
Iterable ORDINAL_DATA = const [
    const ['January',   4.50,  7,  6],
    const ['February',  5.61, 16,  8],
    const ['March',     8.26, 36,  9],
    const ['April',    15.46, 63, 49],
    const ['May',      18.50, 77, 46],
    const ['June',     14.61, 60,  8],
    const ['July',      3.26,  9,  6],
    const ['August',    1.46,  9,  3],
    const ['September', 1.46, 13,  9],
    const ['October',   2.46, 29,  3],
    const ['November',  4.46, 33,  9],
    const ['December',  8.46, 19,  3]
];

/// Sample values used by RTL demos with quantitative dimension scale
Iterable ORDINAL_DATA_RTL = const [
    const ['كانون الثاني',   4.50,  7,  6],
    const ['شباط',  5.61, 16,  8],
    const ['آذار',     8.26, 36,  9],
    const ['نيسان',    15.46, 63, 49],
    const ['أيار',      18.50, 77, 46],
    const ['حزيران',     14.61, 60,  8],
    const ['تموز',      3.26,  9,  6],
    const ['آب',    1.46,  9,  3],
    const ['أيلول', 1.46, 13,  9],
    const ['تشرين الأول',   2.46, 29,  3],
    const ['تشرين الثاني',  4.46, 33,  9],
    const ['كانون الأول',  8.46, 19,  3]
];

Iterable ORDINAL_DATA_WITH_NEGATIVE = const [
    const ['January',   4.50,  -7,   6],
    const ['February',  5.61, -16,   8],
    const ['March',     8.26,  36,   9],
    const ['April',    15.46,  63,  49],
    const ['May',      18.50,  77, -46],
    const ['June',     14.61,  60,   8],
    const ['July',      3.26,   9,   6],
    const ['August',    1.46,   9,   3],
    const ['September', 1.46,  13,   9],
    const ['October',   2.46,  29,   3],
    const ['November',  4.46,  33,   9],
    const ['December',  8.46,  19,   3]
];

Iterable ORDINAL_DATA_WITH_BREAKS = const [
    const ['January',   4.50,  -7,   6],
    const ['February',  5.61, -16,   8],
    const ['March',     8.26,  36,   9],
    const ['April',   null, null, null],
    const ['May',     null, null, null],
    const ['June',     14.61,  60,   8],
    const ['July',      3.26,   9,   6],
    const ['August',    1.46,   9,   3],
    const ['September', 1.46,  13,   9],
    const ['October', null, null, null],
    const ['November',  4.46,  33,   9],
    const ['December',  8.46,  19,   3]
];

/// Sample columns used by demos with quantitative dimension scale
Iterable TIMESERIES_DATA_COLUMNS = [
    new ChartColumnSpec(label: 'Time', type: ChartColumnSpec.TYPE_TIMESTAMP),
    new ChartColumnSpec(label: 'New York'),
    new ChartColumnSpec(label: 'San Fransisco'),
    new ChartColumnSpec(label: 'Austin')
];

Iterable TIMESERIES_DATA = const [
    const [1317452400000, 63.4, 62.7, 72.2],
    const [1317538800000, 58.0, 59.9, 67.7],
    const [1317625200000, 53.3, 59.1, 69.4],
    const [1317711600000, 55.7, 58.8, 68.0],
    const [1317798000000, 64.2, 58.7, 72.4],
    const [1317884400000, 58.8, 57.0, 77.0],
    const [1317970800000, 57.9, 56.7, 82.3],
    const [1318057200000, 61.8, 56.8, 78.9],
    const [1318143600000, 69.3, 56.7, 68.8],
    const [1318230000000, 71.2, 60.1, 68.7],
    const [1318316400000, 68.7, 61.1, 70.3],
    const [1318402800000, 61.8, 61.5, 75.3],
    const [1318489200000, 63.0, 64.3, 76.6],
    const [1318575600000, 66.9, 67.1, 66.6],
    const [1318662000000, 61.7, 64.6, 68.0],
    const [1318748400000, 61.8, 61.6, 70.6],
    const [1318834800000, 62.8, 61.1, 71.1],
    const [1318921200000, 60.8, 59.2, 70.0],
    const [1319007600000, 62.1, 58.9, 61.6],
    const [1319094000000, 65.1, 57.2, 57.4],
    const [1319180400000, 55.6, 56.4, 64.3],
    const [1319266800000, 54.4, 60.7, 72.4],
    const [1319353200000, 54.4, 65.1, 72.4],
    const [1319439600000, 54.8, 60.9, 72.5],
    const [1319526000000, 57.9, 56.1, 72.7],
    const [1319612400000, 54.6, 54.6, 73.4],
    const [1319698800000, 54.4, 56.1, 70.7],
    const [1319785200000, 42.5, 58.1, 56.8],
    const [1319871600000, 40.9, 57.5, 51.0],
    const [1319958000000, 38.6, 57.7, 54.9],
    const [1320044400000, 44.2, 55.1, 58.8],
    const [1320130800000, 49.6, 57.9, 62.6],
    const [1320217200000, 47.2, 64.6, 71.0],
    const [1320303600000, 50.1, 56.2, 58.4],
    const [1320390000000, 50.1, 50.5, 45.1],
    const [1320476400000, 43.5, 51.3, 52.2],
    const [1320562800000, 43.8, 52.6, 73.0],
    const [1320652800000, 48.9, 51.4, 75.4],
    const [1320739200000, 55.5, 50.6, 72.1],
    const [1320825600000, 53.7, 54.6, 56.6],
    const [1320912000000, 57.7, 55.6, 55.4],
    const [1320998400000, 48.5, 53.9, 46.7],
    const [1321084800000, 46.8, 54.0, 62.0],
    const [1321171200000, 51.1, 53.8, 71.6],
    const [1321257600000, 56.8, 53.5, 75.5],
    const [1321344000000, 59.7, 53.4, 72.1],
    const [1321430400000, 56.5, 52.2, 65.7],
    const [1321516800000, 49.6, 52.7, 56.8],
    const [1321603200000, 41.5, 53.1, 49.9],
    const [1321689600000, 44.3, 49.0, 71.7],
    const [1321776000000, 54.0, 50.4, 77.7],
    const [1321862400000, 54.1, 51.1, 76.4],
    const [1321948800000, 49.4, 52.3, 68.8],
    const [1322035200000, 50.0, 54.6, 57.0],
    const [1322121600000, 44.0, 55.1, 55.5],
    const [1322208000000, 50.3, 51.5, 61.6],
    const [1322294400000, 52.1, 53.6, 64.1],
    const [1322380800000, 49.6, 52.3, 51.1],
    const [1322467200000, 57.2, 51.0, 43.0],
    const [1322553600000, 59.1, 49.5, 46.4],
    const [1322640000000, 50.6, 49.8, 48.0],
    const [1322726400000, 44.3, 60.4, 48.1],
    const [1322812800000, 43.9, 62.2, 60.6],
    const [1322899200000, 42.1, 58.3, 62.6],
    const [1322985600000, 43.9, 52.7, 57.1],
    const [1323072000000, 50.2, 51.5, 44.2],
    const [1323158400000, 54.2, 49.9, 37.4],
    const [1323244800000, 54.6, 48.6, 35.0],
    const [1323331200000, 43.4, 46.4, 37.0],
    const [1323417600000, 42.2, 49.8, 45.4],
    const [1323504000000, 45.0, 52.1, 50.7],
    const [1323590400000, 33.8, 48.8, 48.6],
    const [1323676800000, 36.8, 47.4, 52.2],
    const [1323763200000, 38.6, 47.2, 60.8],
    const [1323849600000, 41.9, 46.1, 70.0],
    const [1323936000000, 49.6, 48.8, 64.2],
    const [1324022400000, 50.2, 47.9, 50.9],
    const [1324108800000, 40.6, 49.8, 51.6],
    const [1324195200000, 29.1, 49.1, 55.2],
    const [1324281600000, 33.7, 48.3, 62.1],
    const [1324368000000, 45.8, 49.3, 56.3],
    const [1324454400000, 47.4, 48.4, 47.2],
    const [1324540800000, 54.4, 53.3, 52.3],
    const [1324627200000, 47.8, 47.5, 45.2],
    const [1324713600000, 34.9, 47.9, 43.6],
    const [1324800000000, 35.9, 48.9, 42.9],
    const [1324886400000, 43.6, 45.9, 48.2],
    const [1324972800000, 42.9, 47.2, 45.4],
    const [1325059200000, 46.2, 48.9, 44.2],
    const [1325145600000, 30.8, 50.9, 50.4],
    const [1325232000000, 40.8, 52.9, 52.4],
    const [1325318400000, 49.8, 50.1, 53.5],
    const [1325404800000, 46.3, 53.9, 55.9],
    const [1325491200000, 43.2, 53.1, 48.2],
    const [1325577600000, 30.3, 49.7, 41.0],
    const [1325664000000, 19.2, 52.7, 48.9],
    const [1325750400000, 32.1, 52.6, 54.8],
    const [1325836800000, 41.2, 49.0, 61.2],
    const [1325923200000, 47.0, 51.0, 59.7],
    const [1326009600000, 46.0, 56.8, 52.5],
    const [1326096000000, 34.7, 52.3, 54.0],
    const [1326182400000, 39.4, 51.6, 47.7],
    const [1326268800000, 40.4, 49.8, 49.2],
    const [1326355200000, 45.4, 51.9, 48.4],
    const [1326441600000, 40.7, 53.7, 40.2],
    const [1326528000000, 30.4, 52.9, 43.9],
    const [1326614400000, 23.9, 49.7, 45.2],
    const [1326700800000, 22.6, 45.3, 65.0],
    const [1326787200000, 39.8, 43.6, 68.2],
    const [1326873600000, 43.2, 45.0, 47.5],
    const [1326960000000, 26.3, 47.3, 57.1],
    const [1327046400000, 32.8, 51.4, 61.9],
    const [1327132800000, 27.4, 53.7, 54.6],
    const [1327219200000, 25.0, 48.3, 56.7],
    const [1327305600000, 39.4, 52.9, 54.4],
    const [1327392000000, 48.7, 49.1, 52.7],
    const [1327478400000, 43.0, 52.1, 61.8],
    const [1327564800000, 37.1, 53.6, 55.0],
    const [1327651200000, 48.2, 50.4, 50.7],
    const [1327737600000, 43.7, 50.3, 52.9],
    const [1327824000000, 40.1, 53.8, 44.4],
    const [1327910400000, 38.0, 51.9, 49.1],
    const [1327996800000, 43.5, 50.0, 62.8],
    const [1328083200000, 50.4, 50.0, 64.6],
    const [1328169600000, 45.8, 51.3, 61.1],
    const [1328256000000, 37.5, 51.5, 70.0],
    const [1328342400000, 40.8, 52.0, 61.3],
    const [1328428800000, 36.5, 53.8, 48.2],
    const [1328515200000, 39.1, 54.6, 44.2],
    const [1328601600000, 43.2, 54.3, 51.3],
    const [1328688000000, 36.5, 51.9, 49.2],
    const [1328774400000, 36.5, 53.8, 45.7],
    const [1328860800000, 38.3, 53.9, 54.1],
    const [1328947200000, 36.9, 52.3, 44.9],
    const [1329033600000, 29.7, 50.1, 36.5],
    const [1329120000000, 33.1, 49.5, 44.8],
    const [1329206400000, 39.6, 48.6, 52.3],
    const [1329292800000, 42.3, 49.9, 68.0],
    const [1329379200000, 39.7, 52.4, 54.6],
    const [1329465600000, 46.0, 49.9, 53.8],
    const [1329552000000, 41.2, 51.6, 56.2],
    const [1329638400000, 39.8, 47.8, 50.8],
    const [1329724800000, 38.1, 48.7, 53.0],
    const [1329811200000, 37.1, 49.7, 61.0],
    const [1329897600000, 45.5, 53.4, 68.8],
    const [1329984000000, 50.6, 54.1, 69.4],
    const [1330070400000, 42.7, 55.9, 59.3],
    const [1330156800000, 42.6, 51.7, 47.2],
    const [1330243200000, 36.9, 47.7, 47.7],
    const [1330329600000, 40.9, 45.4, 61.9],
    const [1330416000000, 45.9, 47.0, 67.2],
    const [1330502400000, 40.7, 49.8, 70.1],
    const [1330588800000, 41.3, 48.9, 62.1],
    const [1330675200000, 36.8, 48.1, 72.7],
    const [1330761600000, 47.6, 50.7, 59.0],
    const [1330848000000, 44.2, 55.0, 51.8],
    const [1330934400000, 38.5, 48.8, 55.0],
    const [1331020800000, 32.9, 48.4, 61.8],
    const [1331107200000, 43.3, 49.9, 67.1],
    const [1331193600000, 51.2, 49.2, 72.0],
    const [1331280000000, 47.8, 51.7, 46.4],
    const [1331366400000, 37.2, 49.3, 46.7],
    const [1331452800000, 42.9, 50.0, 56.9],
    const [1331535600000, 48.8, 48.6, 61.9],
    const [1331622000000, 52.6, 53.9, 68.8],
    const [1331708400000, 60.5, 55.2, 71.9],
    const [1331794800000, 47.2, 55.9, 72.0],
    const [1331881200000, 44.7, 54.6, 72.5],
    const [1331967600000, 48.2, 48.2, 71.7],
    const [1332054000000, 48.2, 47.1, 71.1],
    const [1332140400000, 53.1, 45.8, 73.0],
    const [1332226800000, 57.8, 49.7, 63.8],
    const [1332313200000, 57.5, 51.4, 60.0],
    const [1332399600000, 57.3, 51.4, 62.3],
    const [1332486000000, 61.7, 48.4, 61.1],
    const [1332572400000, 55.8, 49.0, 62.0],
    const [1332658800000, 48.4, 46.4, 64.6],
    const [1332745200000, 49.8, 49.7, 66.0],
    const [1332831600000, 39.6, 54.1, 65.8],
    const [1332918000000, 49.7, 54.6, 69.2],
    const [1333004400000, 56.8, 52.3, 69.5],
    const [1333090800000, 46.5, 54.5, 73.5],
    const [1333177200000, 42.2, 56.2, 73.9],
    const [1333263600000, 45.3, 51.1, 75.3],
    const [1333350000000, 48.1, 50.5, 75.4],
    const [1333436400000, 51.2, 52.2, 77.3],
    const [1333522800000, 61.0, 50.6, 67.0],
    const [1333609200000, 50.7, 47.9, 71.1],
    const [1333695600000, 48.0, 47.4, 70.4],
    const [1333782000000, 51.1, 49.4, 73.6],
    const [1333868400000, 55.7, 50.0, 71.1],
    const [1333954800000, 58.3, 51.3, 70.0],
    const [1334041200000, 55.0, 53.8, 69.0],
    const [1334127600000, 49.0, 52.9, 69.2],
    const [1334214000000, 51.7, 53.9, 74.5],
    const [1334300400000, 53.1, 50.2, 73.4],
    const [1334386800000, 55.2, 50.9, 76.0],
    const [1334473200000, 62.3, 51.5, 74.5],
    const [1334559600000, 62.9, 51.9, 63.6],
    const [1334646000000, 69.3, 53.2, 67.3],
    const [1334732400000, 59.0, 53.0, 65.1],
    const [1334818800000, 54.1, 55.1, 67.9],
    const [1334905200000, 56.5, 55.8, 68.9],
    const [1334991600000, 58.2, 58.0, 65.1],
    const [1335078000000, 52.4, 52.8, 65.4],
    const [1335164400000, 51.6, 55.1, 70.1],
    const [1335250800000, 49.3, 57.9, 67.0],
    const [1335337200000, 52.5, 57.5, 75.4],
    const [1335423600000, 50.5, 55.3, 77.5],
    const [1335510000000, 51.9, 53.5, 77.0],
    const [1335596400000, 47.4, 54.7, 77.7],
    const [1335682800000, 54.1, 54.0, 77.7],
    const [1335769200000, 51.9, 53.4, 77.7],
    const [1335855600000, 57.4, 52.7, 77.0],
    const [1335942000000, 53.7, 50.7, 77.9],
    const [1336028400000, 53.1, 52.6, 79.1],
    const [1336114800000, 57.2, 53.4, 80.1],
    const [1336201200000, 57.0, 53.1, 82.1],
    const [1336287600000, 56.6, 56.5, 79.0],
    const [1336374000000, 54.6, 55.3, 79.8],
    const [1336460400000, 57.9, 52.0, 70.0],
    const [1336546800000, 59.2, 52.4, 69.8],
    const [1336633200000, 61.1, 53.4, 71.3],
    const [1336719600000, 59.7, 53.1, 69.4],
    const [1336806000000, 64.1, 49.9, 72.0],
    const [1336892400000, 65.3, 52.0, 72.4],
    const [1336978800000, 64.2, 56.0, 72.5],
    const [1337065200000, 62.0, 53.0, 67.6],
    const [1337151600000, 63.8, 51.0, 69.0],
    const [1337238000000, 64.5, 51.4, 72.7],
    const [1337324400000, 61.0, 52.2, 73.7],
    const [1337410800000, 62.6, 52.4, 77.5],
    const [1337497200000, 66.2, 54.5, 75.8],
    const [1337583600000, 62.7, 52.8, 76.9],
    const [1337670000000, 63.7, 53.9, 78.8],
    const [1337756400000, 66.4, 56.5, 77.7],
    const [1337842800000, 64.5, 54.7, 80.6],
    const [1337929200000, 65.4, 52.5, 81.4],
    const [1338015600000, 69.4, 52.1, 82.3],
    const [1338102000000, 71.9, 52.2, 80.3],
    const [1338188400000, 74.4, 52.9, 80.3],
    const [1338274800000, 75.9, 52.1, 82.2],
    const [1338361200000, 72.9, 52.1, 81.9],
    const [1338447600000, 72.5, 53.3, 82.4],
    const [1338534000000, 67.2, 54.8, 77.9],
    const [1338620400000, 68.3, 54.0, 81.1],
    const [1338706800000, 67.7, 52.3, 82.2],
    const [1338793200000, 61.9, 55.3, 81.2],
    const [1338879600000, 58.3, 53.5, 83.0],
    const [1338966000000, 61.7, 54.1, 83.2],
    const [1339052400000, 66.7, 53.9, 82.1],
    const [1339138800000, 68.7, 54.4, 77.5],
    const [1339225200000, 72.2, 55.0, 77.9],
    const [1339311600000, 72.6, 60.0, 82.9],
    const [1339398000000, 69.2, 57.2, 86.8],
    const [1339484400000, 66.9, 55.1, 85.3],
    const [1339570800000, 66.7, 53.3, 76.9],
    const [1339657200000, 67.7, 53.4, 84.5],
    const [1339743600000, 68.5, 54.6, 84.4],
    const [1339830000000, 67.5, 57.0, 83.8],
    const [1339916400000, 64.2, 55.6, 82.5],
    const [1340002800000, 61.7, 52.5, 82.9],
    const [1340089200000, 66.4, 53.9, 82.5],
    const [1340175600000, 77.9, 55.3, 81.3],
    const [1340262000000, 88.3, 53.3, 80.8],
    const [1340348400000, 82.2, 54.1, 81.7],
    const [1340434800000, 77.0, 55.2, 83.9],
    const [1340521200000, 75.4, 55.8, 85.5],
    const [1340607600000, 70.9, 56.8, 87.2],
    const [1340694000000, 65.9, 57.5, 88.0],
    const [1340780400000, 73.5, 57.7, 89.6],
    const [1340866800000, 77.4, 56.6, 86.7],
    const [1340953200000, 79.6, 56.4, 85.3],
    const [1341039600000, 84.2, 58.4, 81.7],
    const [1341126000000, 81.8, 58.8, 78.5],
    const [1341212400000, 82.5, 56.4, 83.1],
    const [1341298800000, 80.2, 56.5, 83.1],
    const [1341385200000, 77.8, 55.8, 84.5],
    const [1341471600000, 86.1, 54.8, 84.6],
    const [1341558000000, 79.9, 54.9, 84.2],
    const [1341644400000, 83.5, 54.7, 86.7],
    const [1341730800000, 81.5, 52.8, 84.3],
    const [1341817200000, 77.8, 53.7, 83.7],
    const [1341903600000, 76.1, 53.1, 77.1],
    const [1341990000000, 76.3, 52.7, 77.4],
    const [1342076400000, 75.8, 52.0, 80.6],
    const [1342162800000, 77.2, 53.4, 81.4],
    const [1342249200000, 79.3, 54.0, 80.2],
    const [1342335600000, 78.9, 54.0, 81.8],
    const [1342422000000, 79.6, 54.5, 77.3],
    const [1342508400000, 83.3, 56.7, 80.8],
    const [1342594800000, 84.3, 57.5, 81.6],
    const [1342681200000, 75.1, 57.1, 80.9],
    const [1342767600000, 68.4, 58.1, 83.9],
    const [1342854000000, 68.4, 57.6, 85.6],
    const [1342940400000, 72.2, 56.0, 83.6],
    const [1343026800000, 75.6, 56.6, 84.0],
    const [1343113200000, 82.6, 57.8, 83.0],
    const [1343199600000, 78.4, 57.5, 84.8],
    const [1343286000000, 77.0, 56.4, 84.4],
    const [1343372400000, 79.4, 55.3, 84.3],
    const [1343458800000, 77.4, 55.0, 83.9],
    const [1343545200000, 72.5, 55.6, 85.0],
    const [1343631600000, 72.9, 55.6, 84.9],
    const [1343718000000, 73.6, 55.9, 86.3],
    const [1343804400000, 75.0, 55.4, 86.5],
    const [1343890800000, 77.7, 54.4, 85.8],
    const [1343977200000, 79.7, 53.7, 85.3],
    const [1344063600000, 79.6, 54.1, 86.0],
    const [1344150000000, 81.5, 57.8, 84.2],
    const [1344236400000, 80.0, 58.2, 81.9],
    const [1344322800000, 75.7, 58.0, 86.5],
    const [1344409200000, 77.8, 57.0, 86.1],
    const [1344495600000, 78.6, 55.0, 86.8],
    const [1344582000000, 77.8, 54.8, 88.0],
    const [1344668400000, 78.5, 53.0, 85.1],
    const [1344754800000, 78.8, 52.5, 87.4],
    const [1344841200000, 78.6, 53.3, 88.0],
    const [1344927600000, 76.8, 53.9, 88.0],
    const [1345014000000, 76.7, 56.2, 87.2],
    const [1345100400000, 75.9, 57.1, 86.1],
    const [1345186800000, 77.6, 55.3, 86.8],
    const [1345273200000, 72.6, 56.2, 84.9],
    const [1345359600000, 70.4, 54.3, 76.8],
    const [1345446000000, 71.8, 53.1, 80.6],
    const [1345532400000, 73.6, 53.4, 80.0],
    const [1345618800000, 74.7, 54.5, 78.2],
    const [1345705200000, 74.6, 55.7, 79.1],
    const [1345791600000, 76.0, 54.8, 81.9],
    const [1345878000000, 76.2, 53.8, 84.7],
    const [1345964400000, 73.4, 56.5, 83.5],
    const [1346050800000, 74.6, 58.3, 82.1],
    const [1346137200000, 79.4, 58.7, 84.0],
    const [1346223600000, 74.7, 57.5, 85.7],
    const [1346310000000, 73.5, 55.9, 87.2],
    const [1346396400000, 77.9, 55.4, 82.9],
    const [1346482800000, 80.7, 55.7, 84.8],
    const [1346569200000, 75.1, 53.1, 83.9],
    const [1346655600000, 73.5, 53.5, 85.5],
    const [1346742000000, 73.5, 52.5, 86.4],
    const [1346828400000, 77.7, 54.5, 85.8],
    const [1346914800000, 74.2, 56.3, 85.4],
    const [1347001200000, 76.0, 56.4, 85.3],
    const [1347087600000, 77.1, 56.5, 81.9],
    const [1347174000000, 69.7, 56.4, 74.8],
    const [1347260400000, 67.8, 55.4, 71.6],
    const [1347346800000, 64.0, 56.2, 75.9],
    const [1347433200000, 68.1, 55.7, 82.1],
    const [1347519600000, 69.3, 54.3, 80.5],
    const [1347606000000, 70.0, 55.2, 70.0],
    const [1347692400000, 69.3, 54.3, 71.2],
    const [1347778800000, 66.3, 52.9, 70.3],
    const [1347865200000, 67.0, 54.8, 72.1],
    const [1347951600000, 72.8, 54.8, 73.7],
    const [1348038000000, 67.2, 56.8, 72.7],
    const [1348124400000, 62.1, 55.4, 71.7],
    const [1348210800000, 64.0, 55.8, 72.9],
    const [1348297200000, 65.5, 55.9, 73.1],
    const [1348383600000, 65.7, 52.8, 75.6],
    const [1348470000000, 60.4, 54.5, 78.3],
    const [1348556400000, 63.2, 53.3, 78.3],
    const [1348642800000, 68.5, 53.6, 79.6],
    const [1348729200000, 69.2, 52.1, 76.4],
    const [1348815600000, 68.7, 52.6, 77.2],
    const [1348902000000, 62.5, 53.9, 75.2],
    const [1348988400000, 62.3, 55.1, 71.9]
];

